@@ -4,7 +4,10 @@ import os
 import platform
 
 # Need to append all the python subdirectories because Python doesn't recognize them
-sys.path.append('.')
+sys.path.append(os.path.abspath('.'))
+sys.path.append(os.path.abspath(__file__))
+print(os.path.abspath('.'))
+print(os.path.abspath(__file__))
 # Import the necessary library depending on the OS
 if platform.system() == 'Linux':
     import linux_menus
