@@ -1,5 +1,8 @@
 # all imports ---------------
 import sys
+
+sys.path.append('.')
+
 import os
 import ctypes
 from enum import Enum
@@ -282,6 +285,9 @@ class FastRegistryCommand:
 
         set_key_value(command_path, '', new_command)
 
+
+# Testing section...
+
 try:
     def remove_windows_menu(name: str, type: str):
         '''
